
# Slot: load_node_type_list_in_parallel


Whether to load the node type list in parallel. Note that when loading in parallel, the internal order of the node type IDs may result changed across different iterations. We are working to get this to be stable.

URI: [https://w3id.org/neat/ensmallenRunConfig__load_node_type_list_in_parallel](https://w3id.org/neat/ensmallenRunConfig__load_node_type_list_in_parallel)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
